@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import sys
 from pathlib import Path
 from typing import TYPE_CHECKING, Any
 from unittest.mock import ANY
@@ -14,10 +13,7 @@ if TYPE_CHECKING:
 
     from tox.pytest import MonkeyPatch, ToxProjectCreator
 
-if sys.version_info >= (3, 8):  # pragma: no cover (py38+)
-    from typing import Protocol
-else:  # pragma: no cover (<py38)
-    from typing_extensions import Protocol
+from typing import Protocol
 
 
 def test_set_env_explicit() -> None:
@@ -34,6 +30,22 @@ def test_set_env_explicit() -> None:
     assert "MISS" not in set_env
 
 
+def test_set_env_merge() -> None:
+    a = SetEnv("\nA=1\nB = 2\nC= 3\nD= 4", "py", "py", Path())
+    b = SetEnv("\nA=2\nE = 5", "py", "py", Path())
+    a.update(b, override=False)
+
+    keys = list(a)
+    assert keys == ["E", "A", "B", "C", "D"]
+    values = [a.load(k) for k in keys]
+    assert values == ["5", "1", "2", "3", "4"]
+
+    a.update(b, override=True)
+
+    values = [a.load(k) for k in keys]
+    assert values == ["5", "2", "2", "3", "4"]
+
+
 def test_set_env_bad_line() -> None:
     with pytest.raises(ValueError, match="A"):
         SetEnv("A", "py", "py", Path())
