@@ -7,12 +7,15 @@ import signal
 import sys
 import time
 from pathlib import Path
-from types import FrameType
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from types import FrameType
 
 out = sys.stdout
 
 
-def handler(signum: int, _: FrameType | None) -> None:  # noqa: U101
+def handler(signum: int, _: FrameType | None) -> None:
     _p(f"how about no signal {signum!r}")
 
 
